@@ -5,7 +5,7 @@ flexscan=function(map,case,pop,nsim=999,k=10,alpha=0.05,isplot=TRUE,col=c("red",
 
   nb=poly2nb(map)
   listw=nb2listw(nb,style="B", zero.policy=TRUE)
-  w=as(listw,"symmetricMatrix")
+  w=as(listw,"symmetricMatrix")#as_dsTMatrix_listw(listw)
   w=as.matrix(w)
 
   map=map;cases=case;pop=pop;nsim=nsim;k=k;alpha=alpha;isplot=isplot;col=col
